[Bf-blender-cvs] [1419399f032] master: Fix T61919: Rename "Smooth Vertex" -> "Smooth Vertices"

Jacques Lucke noreply at git.blender.org
Mon Feb 25 11:12:23 CET 2019


Commit: 1419399f03235db56f0b18640755b117561c5efb
Author: Jacques Lucke
Date:   Mon Feb 25 11:12:12 2019 +0100
Branches: master
https://developer.blender.org/rB1419399f03235db56f0b18640755b117561c5efb

Fix T61919: Rename "Smooth Vertex" -> "Smooth Vertices"

===================================================================

M	source/blender/editors/mesh/editmesh_tools.c

===================================================================

diff --git a/source/blender/editors/mesh/editmesh_tools.c b/source/blender/editors/mesh/editmesh_tools.c
index ae2abc58a0c..83366987c7a 100644
--- a/source/blender/editors/mesh/editmesh_tools.c
+++ b/source/blender/editors/mesh/editmesh_tools.c
@@ -2133,7 +2133,7 @@ void MESH_OT_normals_make_consistent(wmOperatorType *ot)
 /** \} */
 
 /* -------------------------------------------------------------------- */
 /** \name Smooth Vertex Operator
  * \{ */
 
 static int edbm_do_smooth_vertex_exec(bContext *C, wmOperator *op)
@@ -2218,7 +2218,7 @@ static int edbm_do_smooth_vertex_exec(bContext *C, wmOperator *op)
 void MESH_OT_vertices_smooth(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name = "Smooth Vertex";
+	ot->name = "Smooth Vertices";
 	ot->description = "Flatten angles of selected vertices";
 	ot->idname = "MESH_OT_vertices_smooth";
 
@@ -2242,7 +2242,7 @@ void MESH_OT_vertices_smooth(wmOperatorType *ot)
 /** \} */
 
 /* -------------------------------------------------------------------- */
 /** \name Laplacian Vertex Smooth Operator
  * \{ */
 
 static int edbm_do_smooth_laplacian_vertex_exec(bContext *C, wmOperator *op)
@@ -2339,7 +2339,7 @@ static int edbm_do_smooth_laplacian_vertex_exec(bContext *C, wmOperator *op)
 void MESH_OT_vertices_smooth_laplacian(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name = "Laplacian Smooth Vertex";
+	ot->name = "Laplacian Smooth Vertices";
 	ot->description = "Laplacian smooth of selected vertices";
 	ot->idname = "MESH_OT_vertices_smooth_laplacian";
@@ -2133,7 +2133,7 @@ void MESH_OT_normals_make_consistent(wmOperatorType *ot)
 
 /* -------------------------------------------------------------------- */
-/** \name Smooth Vertex Operator
+/** \name Smooth Vertices Operator
  * \{ */
 
@@ -2242,7 +2242,7 @@ void MESH_OT_vertices_smooth(wmOperatorType *ot)
 
 /* -------------------------------------------------------------------- */
-/** \name Laplacian Vertex Smooth Operator
+/** \name Laplacian Smooth Vertices Operator
  * \{ */
 



More information about the Bf-blender-cvs mailing list